allib package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   allib.activelearning
   allib.analysis
   allib.balancing
   allib.environment
   allib.estimation
   allib.factory
   allib.feature_extraction
   allib.functions
   allib.history
   allib.instances
   allib.labels
   allib.machinelearning
   allib.module
   allib.utils

Submodules
----------

allib.app module
----------------

.. automodule:: allib.app
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: allib
   :members:
   :undoc-members:
   :show-inheritance:
